@@ -493,7 +493,7 @@ test_that("nest_join returns list of tibbles (#3570)",{
 
 test_that("nest_join respects types of y (#6295)",{
   df1 <- tibble(x = c(1, 2), y = c(2, 3))
-  df2 <- rowwise(tibble(x = c(1, 1), z = c(2, 3)))
+  df2 <- duckplyr_rowwise(tibble(x = c(1, 1), z = c(2, 3)))
   out <- duckplyr_nest_join(df1, df2, by = "x")
 
   expect_s3_class(out$df2[[1]], "rowwise_df")
@@ -622,8 +622,8 @@ test_that("joins x preserve type of x", {
 })
 
 test_that("joins preserve groups", {
-  gf1 <- tibble(a = 1:3) %>% group_by(a)
-  gf2 <- tibble(a = rep(1:4, 2), b = 1) %>% group_by(b)
+  gf1 <- tibble(a = 1:3) %>% duckplyr_group_by(a)
+  gf2 <- tibble(a = rep(1:4, 2), b = 1) %>% duckplyr_group_by(b)
 
   i <- count_regroups(out <- duckplyr_inner_join(gf1, gf2, by = "a"))
   expect_equal(i, 1L)
@@ -642,32 +642,32 @@ test_that("joins preserve groups", {
 
 test_that("joins respect zero length groups", {
   df1 <- tibble(f = factor( c(1,1,2,2), levels = 1:3), x = c(1,2,1,4)) %>%
-    group_by(f)
+    duckplyr_group_by(f)
 
   df2 <- tibble(f = factor( c(2,2,3,3), levels = 1:3), y = c(1,2,3,4)) %>%
-    group_by(f)
+    duckplyr_group_by(f)
 
-  expect_equal(group_size(duckplyr_left_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4))
-  expect_equal(group_size(duckplyr_right_join( df1, df2, by = "f", relationship = "many-to-many")),  c(4,2))
-  expect_equal(group_size(duckplyr_full_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4,2))
-  expect_equal(group_size(duckplyr_anti_join( df1, df2, by = "f")),  c(2))
-  expect_equal(group_size(duckplyr_inner_join( df1, df2, by = "f", relationship = "many-to-many")),  c(4))
+  expect_equal(duckplyr_group_size(duckplyr_left_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4))
+  expect_equal(duckplyr_group_size(duckplyr_right_join( df1, df2, by = "f", relationship = "many-to-many")),  c(4,2))
+  expect_equal(duckplyr_group_size(duckplyr_full_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4,2))
+  expect_equal(duckplyr_group_size(duckplyr_anti_join( df1, df2, by = "f")),  c(2))
+  expect_equal(duckplyr_group_size(duckplyr_inner_join( df1, df2, by = "f", relationship = "many-to-many")),  c(4))
 
 
   df1 <- tibble(f = factor( c(1,1,2,2), levels = 1:3), x = c(1,2,1,4)) %>%
-    group_by(f, .drop = FALSE)
+    duckplyr_group_by(f, .drop = FALSE)
   df2 <- tibble(f = factor( c(2,2,3,3), levels = 1:3), y = c(1,2,3,4)) %>%
-    group_by(f, .drop = FALSE)
+    duckplyr_group_by(f, .drop = FALSE)
 
-  expect_equal(group_size(duckplyr_left_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4,0))
-  expect_equal(group_size(duckplyr_right_join( df1, df2, by = "f", relationship = "many-to-many")),  c(0,4,2))
-  expect_equal(group_size(duckplyr_full_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4,2))
-  expect_equal(group_size(duckplyr_anti_join( df1, df2, by = "f")),  c(2,0,0))
-  expect_equal(group_size(duckplyr_inner_join( df1, df2, by = "f", relationship = "many-to-many")),  c(0,4,0))
+  expect_equal(duckplyr_group_size(duckplyr_left_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4,0))
+  expect_equal(duckplyr_group_size(duckplyr_right_join( df1, df2, by = "f", relationship = "many-to-many")),  c(0,4,2))
+  expect_equal(duckplyr_group_size(duckplyr_full_join( df1, df2, by = "f", relationship = "many-to-many")),  c(2,4,2))
+  expect_equal(duckplyr_group_size(duckplyr_anti_join( df1, df2, by = "f")),  c(2,0,0))
+  expect_equal(duckplyr_group_size(duckplyr_inner_join( df1, df2, by = "f", relationship = "many-to-many")),  c(0,4,0))
 })
 
 test_that("group column names reflect renamed duplicate columns (#2330)", {
-  df1 <- tibble(x = 1:5, y = 1:5) %>% group_by(x, y)
+  df1 <- tibble(x = 1:5, y = 1:5) %>% duckplyr_group_by(x, y)
   df2 <- tibble(x = 1:5, y = 1:5)
 
   out <- duckplyr_inner_join(df1, df2, by = "x")
@@ -677,7 +677,7 @@ test_that("group column names reflect renamed duplicate columns (#2330)", {
 })
 
 test_that("rowwise group structure is updated after a join (#5227)", {
-  df1 <- rowwise(tibble(x = 1:2))
+  df1 <- duckplyr_rowwise(tibble(x = 1:2))
   df2 <- tibble(x = c(1:2, 2L))
 
   x <- duckplyr_left_join(df1, df2, by = "x")
